SocialSignInSiteConfig class abstract

Configure site information

Implementers

Constructors

SocialSignInSiteConfig()

Properties

clientId String
getter/setter pair
clientSecret String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
redirectUrl String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope List<String>
getter/setter pair
site SocialPlatform
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited