GitHubSignInResult class

Inheritance
Available extensions

Constructors

GitHubSignInResult(SignInResultStatus status, {String accessToken = "", String idToken = "", String errorMessage = "", String state = ""})

Properties

accessToken ↔ String
getter/setter pairoverride
credential → AuthCredential

Available on SocialSignInResultInterface, provided by the XAuthCredentialBind extension

no setter
errorMessage ↔ String
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
idToken ↔ String
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String
getter/setter pairoverride
status ↔ SignInResultStatus
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited